@@ -11,11 +11,11 @@ WG::API - Module for work with Wargaming.net Public API
 
 =head1 VERSION
 
-Version v0.10
+Version v0.11
 
 =cut
 
-our $VERSION = 'v0.10';
+our $VERSION = 'v0.11';
 
 =head1 SYNOPSIS
 
@@ -74,7 +74,7 @@ sub wot {
 
 =item B<wowp>
 
-Returns A WoWp instance
+Returns a WoWp instance
 
 =back
 
