@@ -1,22 +1,30 @@
 package WG::API::NET;
 
+use Const::Fast;
+use Carp qw/cluck/;
 use Moo;
 
 with 'WG::API::Base';
 
 =head1 NAME
 
-WG::API::NET - Modules to work with Wargaming.net Public API
+WG::API::NET - Module to work with Wargaming.net Public API
 
 =head1 VERSION
 
-Version v0.10
+Version v0.11
 
 =cut
 
-our $VERSION = 'v0.10';
+our $VERSION = 'v0.11';
 
-use constant api_uri => '//api.worldoftanks.ru/';
+const my $api_uri => '//api.worldoftanks.ru/';
+
+sub _api_uri {
+    my ($self) = @_;
+
+    return $api_uri;
+}
 
 =head1 SYNOPSIS
 
@@ -64,9 +72,7 @@ Method returns partial list of players. The list is filtered by initial characte
 =cut
 
 sub accounts_list {
-    my $self = shift;
-
-    return $self->_request( 'get', 'wgn/account/list/', [ 'fields', 'game', 'type', 'search', 'limit', 'language' ], ['search'], @_ );
+    return shift->_request( 'get', 'wgn/account/list/', [ 'fields', 'game', 'type', 'search', 'limit', 'language' ], ['search'], @_ );
 }
 
 =item B<account_info>
@@ -86,11 +92,9 @@ Method returns Wargaming account details.
 =cut
 
 sub account_info {
-    my ( $self, %params ) = @_;
-
-    return $self->_request(
+    return shift->_request(
         'get', 'wgn/account/info/', [ 'fields', 'access_token', 'account_id', 'language' ], ['account_id'],
-        %params
+        @_
     );
 }
 
@@ -100,14 +104,27 @@ sub account_info {
 
 =item B<clans_list>
 
-Method searches through clans and sorts them in a specified order.
+DEPRECATED: Method searches through clans and sorts them in a specified order.
 
 =cut
 
 sub clans_list {
-    my $self = shift;
+    cluck "DEPRECATED!";
+    return shift->_request(
+        'get', 'wgn/clans/list/',
+        [ 'language', 'fields', 'search', 'limit', 'page_no', 'game' ],
+        undef, @_
+    );
+}
 
-    return $self->_request(
+=item B<clans>
+
+Method searches through clans and sorts them in a specified order.
+
+=cut
+
+sub clans {
+    return shift->_request(
         'get', 'wgn/clans/list/',
         [ 'language', 'fields', 'search', 'limit', 'page_no', 'game' ],
         undef, @_
@@ -129,9 +146,7 @@ Method returns detailed clan information.
 =cut
 
 sub clans_info {
-    my $self = shift;
-
-    return $self->_request( 'get', 'wgn/clans/info/', [ 'language', 'fields', 'access_token', 'clan_id', 'extra', 'game', 'members_key' ], ['clan_id'], @_ );
+    return shift->_request( 'get', 'wgn/clans/info/', [ 'language', 'fields', 'access_token', 'clan_id', 'extra', 'game', 'members_key' ], ['clan_id'], @_ );
 }
 
 =item B<clans_membersinfo>
@@ -149,9 +164,7 @@ Method returns clan member info and short info on the clan. Information is avail
 =cut
 
 sub clans_membersinfo {
-    my $self = shift;
-
-    return $self->_request( 'get', 'wgn/clans/membersinfo/', [ 'language', 'fields', 'account_id', 'game' ], ['account_id'], @_ );
+    return shift->_request( 'get', 'wgn/clans/membersinfo/', [ 'language', 'fields', 'account_id', 'game' ], ['account_id'], @_ );
 }
 
 =item B<clans_glossary>
@@ -161,9 +174,7 @@ Method returns information on clan entities in World of Tanks and World of Warpl
 =cut
 
 sub clans_glossary {
-    my $self = shift;
-
-    return $self->_request( 'get', 'wgn/clans/glossary/', [ 'language', 'fields', 'game' ], undef, @_ );
+    return shift->_request( 'get', 'wgn/clans/glossary/', [ 'language', 'fields', 'game' ], undef, @_ );
 }
 
 =item B<clans_messageboard>
@@ -181,9 +192,7 @@ Method returns messages of clan message board.
 =cut
 
 sub clans_messageboard {
-    my $self = shift;
-
-    return $self->_request(
+    return shift->_request(
         'get', 'wgn/clans/mesageboard/', [ 'game', 'fields', 'access_token' ], ['access_token'],
         @_
     );
@@ -206,9 +215,7 @@ Method returns information about player's clan history. Data on 10 last clan mem
 =cut
 
 sub clans_memberhistory {
-    my $self = shift;
-
-    return $self->_request(
+    return shift->_request(
         'get', 'wgn/clans/memberhistory/', [ 'game', 'fields', 'account_id', 'language' ], ['account_id'],
         @_
     );
@@ -227,9 +234,7 @@ Method returns the number of online players on the servers.
 =cut
 
 sub servers_info {
-    my ( $self, %params ) = @_;
-
-    return $self->_request( 'get', 'wgn/servers/info/', [ 'language', 'fields', 'game' ], undef, %params );
+    return shift->_request( 'get', 'wgn/servers/info/', [ 'language', 'fields', 'game' ], undef, @_ );
 }
 
 =head1 BUGS
